==> qtjambi-bluetooth-debuginfo-macos-5.15.18.jar: sources/QtJambiBluetooth/QBluetoothHostInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtBluetooth/qbluetoothhostinfo.h>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiBluetooth/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBluetoothHostInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBluetoothHostInfo")
    QBluetoothHostInfo *_ptr = reinterpret_cast<QBluetoothHostInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBluetoothHostInfo()
void __qt_construct_QBluetoothHostInfo_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothHostInfo()")
    Q_UNUSED(__java_arguments)
    QBluetoothHostInfo *__qt_this = new(__qtjambi_ptr) QBluetoothHostInfo();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QBluetoothHostInfo(QBluetoothHostInfo)
void __qt_construct_QBluetoothHostInfo_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothHostInfo(QBluetoothHostInfo)")
    jobject other0 = __java_arguments[0].l;
    const QBluetoothHostInfo& __qt_other0 = qtjambi_cast<const QBluetoothHostInfo& >(__jni_env, other0);
    QBluetoothHostInfo *__qt_this = new(__qtjambi_ptr) QBluetoothHostInfo(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QBluetoothHostInfo
void __qt_destruct_QBluetoothHostInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBluetoothHostInfo")
    reinterpret_cast<QBluetoothHostInfo*>(ptr)->~QBluetoothHostInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBluetoothHostInfo::QBluetoothHostInfo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_initialize_1native__Lio_qt_bluetooth_QBluetoothHostInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothHostInfo::QBluetoothHostInfo()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothHostInfo_0, sizeof(QBluetoothHostInfo), typeid(QBluetoothHostInfo), false, &deleter_QBluetoothHostInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothHostInfo::QBluetoothHostInfo(QBluetoothHostInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_initialize_1native__Lio_qt_bluetooth_QBluetoothHostInfo_2Lio_qt_bluetooth_QBluetoothHostInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothHostInfo::QBluetoothHostInfo(QBluetoothHostInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothHostInfo_1, sizeof(QBluetoothHostInfo), typeid(QBluetoothHostInfo), false, &deleter_QBluetoothHostInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothHostInfo::address()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_address_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::address()const", __qt_this)
        QBluetoothAddress __qt_return_value = __qt_this->address();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothHostInfo::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothHostInfo::operator=(QBluetoothHostInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_assign_1native_1cref_1QBluetoothHostInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::operator=(QBluetoothHostInfo)", __qt_this)
        const QBluetoothHostInfo& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothHostInfo>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothHostInfo::operator==(QBluetoothHostInfo)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_equals_1native_1cref_1QBluetoothHostInfo_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::operator==(QBluetoothHostInfo)const", __qt_this)
        const QBluetoothHostInfo& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothHostInfo>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothHostInfo::setAddress(QBluetoothAddress)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_setAddress_1native_1cref_1QBluetoothAddress__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID address0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::setAddress(QBluetoothAddress)", __qt_this)
        const QBluetoothAddress& __qt_address0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothAddress>(address0);
        __qt_this->setAddress(__qt_address0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothHostInfo::setName(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_setName_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring name0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::setName(QString)", __qt_this)
        QString  __qt_name0 = qtjambi_cast<QString>(__jni_env, name0);
        __qt_this->setName(__qt_name0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBluetoothHostInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QBluetoothHostInfo>("QBluetoothHostInfo", "io/qt/bluetooth/QBluetoothHostInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBluetoothHostInfo, {
        ConstructorInfo(&__qt_construct_QBluetoothHostInfo_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QBluetoothHostInfo_1, "Lio/qt/bluetooth/QBluetoothHostInfo;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBluetoothHostInfo);
    registerMetaType<QBluetoothHostInfo>("QBluetoothHostInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-bluetooth-debuginfo-macos-5.15.20.jar: sources/QtJambiBluetooth/QBluetoothHostInfo_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtBluetooth/qbluetoothhostinfo.h>
#include <QtBluetooth/qbluetoothaddress.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiBluetooth/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBluetoothHostInfo(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBluetoothHostInfo")
    QBluetoothHostInfo *_ptr = reinterpret_cast<QBluetoothHostInfo *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBluetoothHostInfo()
void __qt_construct_QBluetoothHostInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothHostInfo()")
    Q_UNUSED(__java_arguments)
    QBluetoothHostInfo *__qt_this = new(__qtjambi_ptr) QBluetoothHostInfo();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QBluetoothHostInfo::QBluetoothHostInfo()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_initialize_1native__Lio_qt_bluetooth_QBluetoothHostInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothHostInfo::QBluetoothHostInfo()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothHostInfo, sizeof(QBluetoothHostInfo), typeid(QBluetoothHostInfo), false, &deleter_QBluetoothHostInfo, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QBluetoothHostInfo(QBluetoothHostInfo)
void __qt_construct_QBluetoothHostInfo_cref_QBluetoothHostInfo(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBluetoothHostInfo(QBluetoothHostInfo)")
    jobject other0 = __java_arguments[0].l;
    const QBluetoothHostInfo& __qt_other0 = qtjambi_cast<const QBluetoothHostInfo& >(__jni_env, other0);
    QBluetoothHostInfo *__qt_this = new(__qtjambi_ptr) QBluetoothHostInfo(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QBluetoothHostInfo::QBluetoothHostInfo(QBluetoothHostInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_initialize_1native__Lio_qt_bluetooth_QBluetoothHostInfo_2Lio_qt_bluetooth_QBluetoothHostInfo_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBluetoothHostInfo::QBluetoothHostInfo(QBluetoothHostInfo)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBluetoothHostInfo_cref_QBluetoothHostInfo, sizeof(QBluetoothHostInfo), typeid(QBluetoothHostInfo), false, &deleter_QBluetoothHostInfo, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBluetoothHostInfo
void __qt_destruct_QBluetoothHostInfo(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBluetoothHostInfo")
    reinterpret_cast<QBluetoothHostInfo*>(ptr)->~QBluetoothHostInfo();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBluetoothHostInfo::address()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_address_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::address()const", __qt_this)
        QBluetoothAddress __qt_return_value = __qt_this->address();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothHostInfo::name()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_name_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::name()const", __qt_this)
        QString __qt_return_value = __qt_this->name();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothHostInfo::operator=(QBluetoothHostInfo)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_assign_1native_1cref_1QBluetoothHostInfo__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::operator=(QBluetoothHostInfo)", __qt_this)
        const QBluetoothHostInfo& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothHostInfo>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothHostInfo::operator==(QBluetoothHostInfo)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_equals_1native_1cref_1QBluetoothHostInfo_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::operator==(QBluetoothHostInfo)const", __qt_this)
        const QBluetoothHostInfo& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothHostInfo>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBluetoothHostInfo::setAddress(QBluetoothAddress)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_setAddress_1native_1cref_1QBluetoothAddress__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID address0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::setAddress(QBluetoothAddress)", __qt_this)
        const QBluetoothAddress& __qt_address0 = QtJambiAPI::valueReferenceFromNativeId<QBluetoothAddress>(address0);
        __qt_this->setAddress(__qt_address0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBluetoothHostInfo::setName(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_setName_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring name0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBluetoothHostInfo::setName(QString)", __qt_this)
        QString  __qt_name0 = qtjambi_cast<QString>(__jni_env, name0);
        __qt_this->setName(__qt_name0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_bluetooth_QBluetoothHostInfo_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QBluetoothHostInfo *__qt_this = QtJambiAPI::objectFromNativeId<QBluetoothHostInfo>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QBluetoothHostInfo(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QBluetoothHostInfo>("QBluetoothHostInfo", "io/qt/bluetooth/QBluetoothHostInfo");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBluetoothHostInfo, {
        ConstructorInfo(&__qt_construct_QBluetoothHostInfo, nullptr)
       ,ConstructorInfo(&__qt_construct_QBluetoothHostInfo_cref_QBluetoothHostInfo, "Lio/qt/bluetooth/QBluetoothHostInfo;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBluetoothHostInfo);
    registerMetaType<QBluetoothHostInfo>("QBluetoothHostInfo");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
